@@ -1,74 +1,12 @@
 // Host Autocomplete Magic
 var pageName = basename($(location).attr('pathname'));
 
-/* only perform the recalculation of elements at the final end of the windows resize event */
-var waitForFinalEvent = (function () {
-  var timers = {};
-  return function (callback, ms, uniqueId) {
-    if (!uniqueId) {
-      uniqueId = "Don't call this twice without a uniqueId";
-    }
-    if (timers[uniqueId]) {
-      clearTimeout (timers[uniqueId]);
-    }
-    timers[uniqueId] = setTimeout(callback, ms);
-  };
-})();
-
-function keepWindowSize() {
-	$(window).resize(function (event) {
-		waitForFinalEvent(function(){
-			/* close open dropdown menues first off */
-			$('.dropdownMenu > ul').hide();
-
-			heightPage = $(window).height();
-			heightPageHead = $('#cactiPageHead').outerHeight();
-			heightPageBottom = $('#cactiPageBottom').outerHeight();
-			heightPageContent = heightPage -heightPageHead -heightPageBottom +1;
-
-			$('body').css('height', heightPage);
-			$('#cactiContent').css('height', heightPageContent);
-
-			$('.cactiTreeNavigationArea').css('height', heightPageContent);
-			width = parseInt($('#searcher').width())+65;
-			$('.cactiTreeNavigationArea').css('width', width+'px');
-			$('.cactiTreeNavigationArea > div').css('padding-top', '5px');
-
-			/* check visibility of all tabs */
-			$('#submenu-ellipsis').empty();
-			$('.maintabs nav ul li a').each(function() {
-				id = $(this).attr('id');
-				if( $(this).offset().top !== 0 ) {
-					if( $('#' + id + '-ellipsis').length == 0 ) {
-						var str = $(this).parent().html();
-						var str2 = str.replace( id , id + '-ellipsis');
-						$('#submenu-ellipsis').prepend('<li>' + str2 + '</li>');
-						$('#'+ id + '-ellipsis').css('visibility','');
-						$(this).css('visibility', 'hidden');
-					}
-				}else {
-					$('#' + id + '-ellipsis').parent().remove();
-					$(this).css('visibility', 'visible');
-				}
-			});
-
-			if($("#submenu-ellipsis li").length == 0) {
-				$(".ellipsis").hide(0);
-			}else {
-				$(".ellipsis").show(0);
-			}
-		}, 200, "resize-content");
-	});
-}
-
 function themeReady() {
 	var pageName = basename($(location).attr('pathname'));
 	var hostTimer = false;
 	var clickTimeout = false;
 	var hostOpen = false;
 
-	keepWindowSize();
-
 	// Setup the navigation menu
 	setMenuVisibility();
 
@@ -95,93 +33,72 @@ function themeReady() {
 	$('.cactiLoginLogo').html("<i class='fa fa-paper-plane'/>");
 	$('.cactiLogoutLogo').html("<i class='fa fa-paper-plane'/>");
 
-
 	/* clean up the navigation menu */
 	$('.cactiConsoleNavigationArea').find('#menu').appendTo($('.cactiConsoleNavigationArea').find('#navigation'));
 	$('.cactiConsoleNavigationArea').find('#navigation > table').remove();
 
-	/* 'ellipsis' menu in the middle */
-	if ($('.ellipsis').length == 0) {
-		$('<div class="maintabs ellipsis">'
-			+'<nav><ul>'
-				+'<li class="maintabs-submenu">'
-					+'<a class="submenu-ellipsis" href="#"><i class="fa fa-caret-down"></i></a></li>'
-			+'</ul></nav>'
-		+'</div>').insertAfter('.maintabs');
-	}
-	$('<div class="dropdownMenu">'
-		+'<ul id="submenu-ellipsis" class="submenuoptions" style="display:none;">'
-		+'</ul>'
-	+'</div>').appendTo('body');
-	$('<div class="dropdownMenu">'
-		+'<ul id="submenu-ellipsis" class="submenuoptions" style="display:none;">'
-		+'</ul>'
-	+'</div>').appendTo('body');
-
-	/* Hey - No footer available ? */
-	if($('#cactiPageBottom').length == 0) {
+	if ($('#cactiPageBottom').length == 0) {
 		$('<div id="cactiPageBottom" class="cactiPageBottom"><a class="bottom_scroll_up action-icon-user" href="#"><i class="fa fa-arrow-circle-o-up"></i></a></div>').insertAfter('#cactiContent');
 	}
-	/* Console? Nope! */
-	submenu_counter = 10;
 
-	$('.maintabs nav ul li a').each( function() {
+	$('.maintabs nav ul li a.lefttab').each( function() {
 		id = $(this).attr('id');
-		if ( id == 'maintab-anchor-console') {
-			$(this).html("<i class='fa fa-paper-plane'/>");
-		}else if ( id == 'maintab-anchor-graphs' && $(this).parent().hasClass('maintabs-has-submenu') == 0 ) {
-			submenu_counter++;
+
+		if (id == 'tab-graphs' && $(this).parent().hasClass('maintabs-has-submenu') == 0) {
 			$(this).parent().addClass('maintabs-has-submenu');
-			$('<li class="maintabs-submenu"><a class="submenu-' + submenu_counter + '" href="#"><i class="fa fa-caret-down"></i></a></li>').insertAfter( $(this) );
 			$('<div class="dropdownMenu">'
-				+'<ul id="submenu-' + submenu_counter + '" class="submenuoptions" style="display:none;">'
+				+'<ul id="submenu-tab-graphs" class="submenuoptions" style="display:none;">'
 					+'<li><a href="'+urlPath+'graph_view.php?action=tree"><span>'+treeView+'</span></a></li>'
 					+'<li><a href="'+urlPath+'graph_view.php?action=list"><span>'+listView+'</span></a></li>'
 					+'<li><a href="'+urlPath+'graph_view.php?action=preview"><span>'+previewView+'</span></a></li>'
 				+'</ul>'
 			+'</div>').appendTo('body');
-		}else {
+		} else {
 			/* plugin stuff here ? */
 		}
 	});
 
 	/* user menu on the right ... */
 	if ($('.usertabs').length == 0) {
+		$('#userDocumentation').remove();
+		$('#userCommunity').remove();
+		$('.menuHr').remove();
 		$('<div class="maintabs usertabs">'
 			+'<nav><ul>'
-				+'<li class="usertabs-submenu"><a class="submenu-user-help" href="#"><i class="fa fa-question"></i></a></li>'
+				+'<li><a id="menu-user-help" class="usertabs-submenu" href="#"><i class="fa fa-question"></i></a></li>'
 				+'<li class="action-icon-user"><a class="pic" href="#"><i class="fa fa-user"></i></a></li>'
 			+'</ul></nav>'
-		+'</div>').insertAfter('.ellipsis');
+		+'</div>').insertAfter('.maintabs');
+
 		$('<div class="dropdownMenu">'
 			+'<ul id="submenu-user-help" class="submenuoptions right" style="display:none;">'
-				+'<li><a href="http://www.cacti.net" target="_blank"><span>'+cactiHome+'</span></a></li>'
+				+'<li><a href="https://www.cacti.net" target="_blank"><span>'+cactiHome+'</span></a></li>'
 				+'<li><a href="https://github.com/cacti" target="_blank"><span>'+cactiProjectPage+'</span></a></li>'
-				+'<li><a href="http://forums.cacti.net/" target="_blank"><span>'+cactiCommunityForum+'</span></a></li>'
+				+'<li><hr class="menu"></li>'
+				+'<li><a href="https://forums.cacti.net/" target="_blank"><span>'+cactiCommunityForum+'</span></a></li>'
+				+'<li><a href="https://github.com/Cacti/documentation/blob/develop/README.md" target="_blank"><span>'+cactiDocumentation+'</span></a></li>'
+				+'<li><hr class="menu"></li>'
 				+'<li><a href="https://github.com/Cacti/cacti/issues/new" target="_blank"><span>'+reportABug+'</span></a></li>'
 				+'<li><a href="'+urlPath+'about.php"><span>'+aboutCacti+'</span></a></li>'
 			+'</ul>'
 		+'</div>').appendTo('body');
 	}
 
-
-
 	ajaxAnchors();
 
 	/* User Menu */
 	$('.menuoptions').parent().appendTo('body');
 
-	$(window).trigger('resize');
-
 	$('.action-icon-user').unbind().click(function(event) {
 		event.preventDefault();
 
-		if( $('.menuoptions').is(':visible') === false ) {
+		if ($('.menuoptions').is(':visible') === false) {
 			$('.submenuoptions').stop().slideUp(120);
 			$('.menuoptions').stop().slideDown(120);
-		}else {
+		} else {
 			$('.menuoptions').stop().slideUp(120);
 		}
+
 		return false;
 	});
 
@@ -190,53 +107,15 @@ function themeReady() {
 		$('#navigation_right').animate({ scrollLeft:0, scrollTop: 0 }, 1000, 'easeInOutQuart');
 	});
 
-
-	$('.maintabs-submenu, .usertabs-submenu').unbind('click').click(function(event) {
-		event.preventDefault();
-
-		submenu_index = $(this).children('a:first').attr('class');
-		submenu = $('#'+submenu_index);
-
-		if( submenu.is(':visible') === false ) {
-			/* close other drop down menus first */
-			$('.submenuoptions').stop().slideUp(120);
-			$('.menuoptions').stop().slideUp(120);
-			/* re-position */
-			position = $(this).parent('.maintabs-has-submenu').position();
-			if(!position) {
-				position = $(this).position();
-				submenu.css({'left':position.left - parseInt(submenu.outerWidth()) + parseInt($(this).outerWidth()) }).slideDown(120);
-			}else {
-				/* move dd to the left */
-				submenu.css({'left':position.left}).slideDown(120);
-			}
-		}else {
-			submenu.slideUp(120);
-		}
-
-		return false;
-	});
-
-	$('.submenuoptions').mouseenter(function(data) {
-		clearTimeout(userMenuTimer);
-	}).mouseleave(function(data) {
-		if ($('.submenuoptions').is(':visible')) {
-			userMenuTimer = setTimeout(function() {$('.submenuoptions').stop().slideUp(120);}, 1000);
-		}else{
-			clearTimeout(userMenuOpenTimer);
-		}
-	});
-
-
 	/* Highlight sortable table columns */
-	$('.tableHeader th').has('i.fa-unsorted').removeClass('tableHeaderColumnHover tableHeaderColumnSelected');
-	$('.tableHeader th').has('i.fa-sort-asc').addClass('tableHeaderColumnSelected');
-	$('.tableHeader th').has('i.fa-sort-desc').addClass('tableHeaderColumnSelected');
-	$('.tableHeader th').has('i.fa-unsorted').hover(
+	$('.tableHeader th').has('i.fa-sort').removeClass('tableHeaderColumnHover tableHeaderColumnSelected');
+	$('.tableHeader th').has('i.fa-sort-up').addClass('tableHeaderColumnSelected');
+	$('.tableHeader th').has('i.fa-sort-down').addClass('tableHeaderColumnSelected');
+	$('.tableHeader th').has('i.fa-sort').hover(
 		function() {
-			$( this ).addClass("tableHeaderColumnHover" );
+			$(this).addClass("tableHeaderColumnHover");
 		}, function() {
-			$( this ).removeClass( "tableHeaderColumnHover" );
+			$(this).removeClass( "tableHeaderColumnHover");
 		}
 	);
 
@@ -260,30 +139,24 @@ function themeReady() {
 
 	$('select').not('.colordropdown').each(function() {
 		if ($(this).prop('multiple') != true) {
-			$(this).selectmenu({
-				change: function(event, ui) {
-					$(this).val(ui.item.value).change();
-				},
-				position: {
-					my: "left top",
-					at: "left bottom",
-					collision: "flip"
-				},
-			}).each(function() {
+			$(this).each(function() {
 				id = $(this).attr('id');
-				minWidth = 0;
-				$('#'+id+' > option').each(function() {
-					width=$(this).textWidth();
-					if (width > minWidth) {
-						minWidth = width;
-					}
+
+				$(this).selectmenu({
+					change: function(event, ui) {
+						$(this).val(ui.item.value).change();
+					},
+					position: {
+						my: "left top",
+						at: "left bottom",
+						collision: "flip"
+					},
+					width: 'auto'
 				});
 
-				minWidth+=80;
-				$('#'+id+'-button').css('min-width', minWidth+'px').css('max-width', '400px').css('width','');
 				$('#'+id+'-menu').css('max-height', '250px');
 			});
-		}else{
+		} else{
 			$(this).addClass('ui-state-default ui-corner-all');
 		}
 	});
@@ -297,9 +170,9 @@ function themeReady() {
 			callBack = $('#call_back').val();
 			if (callBack != 'undefined') {
 				eval(callBack);
-			}else if (typeof applyGraphFilter === 'function') {
+			} else if (typeof applyGraphFilter === 'function') {
 				applyGraphFilter();
-			}else{
+			} else{
 				applyFilter();
 			}
 		}
@@ -309,26 +182,16 @@ function themeReady() {
 		if (!hostOpen) {
 			$('#host').autocomplete('option', 'minLength', 0).autocomplete('search', '');
 			hostOpen = true;
-		}else{
+		} else{
 			$('#host').autocomplete('close');
 			hostOpen = false;
 		}
 	});
 
-/* End clean up */
-
-
-	/* Notification Handler */
-	if( $("#message").length ) {
-	//	alert($('#message_container').html());
-	}
-
 	/* Replace icons */
 	$('.fa-arrow-down').addClass('fa-chevron-down').removeClass('fa-arrow-down');
 	$('.fa-arrow-up').addClass('fa-chevron-up').removeClass('fa-arrow-up');
 	$('.fa-remove').addClass('fa-trash-o').removeClass('fa-remove');
-
-
 }
 
 function setMenuVisibility() {
@@ -339,14 +202,12 @@ function setMenuVisibility() {
 	$('#navigation').hide();
 	$('li.menuitem').each(function() {
 		active = storage.get($(this).attr('id'));
-		if (active != null) {
-			if (active == 'active') {
-				$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
-				$(this).next('a').show();
-			}else{
-				$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
-				$(this).next('a').hide();
-			}
+		if (active != null && active == 'active') {
+			$(this).find('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true').show();
+			$(this).next('a').show();
+		} else{
+			$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false').hide();
+			$(this).next('a').hide();
 		}
 
 		if ($(this).find('a.selected').length) {
@@ -373,14 +234,14 @@ function setMenuVisibility() {
 
 		if ($(this).next().is(':visible')){
 			$(this).next('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false');
-			$(this).next().slideUp( { duration: 200, easing: 'swing' } );
+			$(this).next().slideUp({ duration: 200, easing: 'swing' });
 			storage.set($(this).closest('.menuitem').attr('id'), 'collapsed');
 		} else {
 			$(this).next('ul').attr('aria-hidden', 'false').attr('aria-expanded', 'true');
-			$(this).next().slideToggle( { duration: 200, easing: 'swing' } );
+			$(this).next().slideToggle({ duration: 200, easing: 'swing' });
 			if ($(this).next().is(':visible')) {
 				storage.set($(this).closest('.menuitem').attr('id'), 'active');
-			}else{
+			} else{
 				storage.set($(this).closest('.menuitem').attr('id'), 'collapsed');
 			}
 		}
@@ -390,8 +251,9 @@ function setMenuVisibility() {
 			id   = $(this).attr('id');
 
 			$(this).find('ul').attr('aria-hidden', 'true').attr('aria-expanded', 'false');
-			$(this).find('ul').slideUp( { duration: 200, easing: 'swing' } );
+			$(this).find('ul').slideUp({ duration: 200, easing: 'swing' });
 			storage.set($(this).attr('id'), 'collapsed');
 		});
 	});
 }
+
