@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -363,7 +363,7 @@ function api_tree_delete_node_content($tree_id, $leaf_id) {
 
 	if (cacti_sizeof($children)) {
 		foreach($children as $child) {
-			if ($child['host_id'] == 0 && $child['graph_id'] == 0) {
+			if ($child['host_id'] == 0 && $child['local_graph_id'] == 0) {
 				api_tree_delete_node_content($tree_id, $child['id']);
 			}
 
