@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2018 The Cacti Group                                 |
+ | Copyright (C) 2004-2019 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -200,9 +200,14 @@ function substitute_host_data($string, $l_escape_string, $r_escape_string, $host
 	if (!empty($host_id)) {
 		if (!isset($_SESSION['sess_host_cache_array'][$host_id])) {
 			$host = db_fetch_row_prepared('SELECT ' . SQL_NO_CACHE . ' * FROM host WHERE id = ?', array($host_id));
+			if (!cacti_sizeof($host)) {
+				return $string;
+			}
+
 			$_SESSION['sess_host_cache_array'][$host_id] = $host;
 		}
 
+
 		$search  = array();
 		$replace = array();
 
