@@ -1,10 +1,6 @@
+#!/bin/php -q
 <?php
-#!/usr/bin/php -q
 
-/* do NOT run this script through a web browser */
-$no_http_headers = true;
-
-/* display no errors */
 error_reporting(0);
 
 include_once(dirname(__FILE__) . '/../include/cli_check.php');
@@ -13,9 +9,9 @@ include_once(dirname(__FILE__) . '/../lib/ping.php');
 
 if (!isset($called_by_script_server)) {
 	array_shift($_SERVER['argv']);
+
 	print call_user_func_array('ss_fping', $_SERVER['argv']);
 }
-//End header.
 
 function ss_fping($hostname, $ping_sweeps=6, $ping_type='ICMP', $port=80) {
 	/* record start time */
